package com.yinet.bjtj.service;

import com.yinet.bjtj.domain.BjljStatistics;
import com.yinet.common.core.domain.AjaxResult;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 * 
 * @author yinet
 * @date 2020-04-23
 */
public interface IBjljStatisticsService 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public BjljStatistics selectBjljStatisticsById(Integer id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param bjljStatistics 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<BjljStatistics> selectBjljStatisticsList(BjljStatistics bjljStatistics);

    /**
     * 新增【请填写功能名称】
     * 
     * @param bjljStatistics 【请填写功能名称】
     * @return 结果
     */
    public int insertBjljStatistics(BjljStatistics bjljStatistics);

    /**
     * 修改【请填写功能名称】
     * 
     * @param bjljStatistics 【请填写功能名称】
     * @return 结果
     */
    public int updateBjljStatistics(BjljStatistics bjljStatistics);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBjljStatisticsByIds(String ids);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteBjljStatisticsById(Integer id);

    //总计
    String BjljStatisticsQuantitySum();
    //总计个体
    String BjljStatisticsTypeSum(String type);

    //总计企业
    String BjljStatisticsNumberSum(String type);
    //总计乡镇个数
    String BjljStatisticsAreaNameSum(String areaName);
}
